pylbm.elements.Cylinder\_Ellipse
================================

.. currentmodule:: pylbm.elements

.. autoclass:: Cylinder_Ellipse

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Cylinder_Ellipse.change_of_variables
         Cylinder_Ellipse.distance
         Cylinder_Ellipse.get_bounds
         Cylinder_Ellipse.point_inside
         Cylinder_Ellipse.test_label



   

